@@ -103,9 +103,9 @@ typedef enum {
  * Since: 0.11.8
  */
 typedef enum {
-  FLATPAK_UNINSTALL_FLAGS_NONE        = 0,
-  FLATPAK_UNINSTALL_FLAGS_NO_PRUNE    = (1 << 0),
-  FLATPAK_UNINSTALL_FLAGS_NO_TRIGGERS = (1 << 1),
+  FLATPAK_UNINSTALL_FLAGS_NONE            = 0,
+  FLATPAK_UNINSTALL_FLAGS_NO_PRUNE        = (1 << 0),
+  FLATPAK_UNINSTALL_FLAGS_NO_TRIGGERS     = (1 << 1),
 } FlatpakUninstallFlags;
 
 /**
@@ -121,6 +121,22 @@ typedef enum {
   FLATPAK_LAUNCH_FLAGS_DO_NOT_REAP = (1 << 0),
 } FlatpakLaunchFlags;
 
+/**
+ * FlatpakQueryFlags:
+ * @FLATPAK_QUERY_FLAGS_NONE: Default
+ * @FLATPAK_QUERY_FLAGS_ONLY_CACHED: Don't do any network i/o, but only return cached data.
+ * This can return stale data, or a #FLATPAK_ERROR_NOT_CACHED error, however it is a
+ * lot more efficient if you're doing many requests.
+ *
+ * Flags to alter the behavior of e.g flatpak_installation_list_remote_refs_full().
+ *
+ * Since: 1.3.3
+ */
+typedef enum {
+  FLATPAK_QUERY_FLAGS_NONE        = 0,
+  FLATPAK_QUERY_FLAGS_ONLY_CACHED = (1 << 0),
+} FlatpakQueryFlags;
+
 /**
  * FlatpakStorageType:
  * @FLATPAK_STORAGE_TYPE_DEFAULT: default
@@ -163,6 +179,9 @@ FLATPAK_EXTERN FlatpakInstallation *flatpak_installation_new_for_path (GFile
                                                                        gboolean      user,
                                                                        GCancellable *cancellable,
                                                                        GError      **error);
+FLATPAK_EXTERN void flatpak_installation_set_no_interaction (FlatpakInstallation *self,
+                                                             gboolean             no_interaction);
+FLATPAK_EXTERN gboolean flatpak_installation_get_no_interaction (FlatpakInstallation *installation);
 
 /**
  * FlatpakProgressCallback:
@@ -220,6 +239,10 @@ FLATPAK_EXTERN GPtrArray           *flatpak_installation_list_installed_refs_by_
 FLATPAK_EXTERN GPtrArray           *flatpak_installation_list_installed_refs_for_update (FlatpakInstallation *self,
                                                                                          GCancellable        *cancellable,
                                                                                          GError             **error);
+FLATPAK_EXTERN GPtrArray           *flatpak_installation_list_unused_refs (FlatpakInstallation *self,
+                                                                           const char          *arch,
+                                                                           GCancellable        *cancellable,
+                                                                           GError             **error);
 FLATPAK_EXTERN FlatpakInstalledRef * flatpak_installation_get_installed_ref (FlatpakInstallation *self,
                                                                              FlatpakRefKind       kind,
                                                                              const char          *name,
@@ -244,6 +267,11 @@ FLATPAK_EXTERN FlatpakRemote        *flatpak_installation_get_remote_by_name (Fl
                                                                               const gchar         *name,
                                                                               GCancellable        *cancellable,
                                                                               GError             **error);
+FLATPAK_EXTERN gboolean              flatpak_installation_add_remote (FlatpakInstallation *self,
+                                                                      FlatpakRemote       *remote,
+                                                                      gboolean             if_needed,
+                                                                      GCancellable        *cancellable,
+                                                                      GError             **error);
 FLATPAK_EXTERN gboolean              flatpak_installation_modify_remote (FlatpakInstallation *self,
                                                                          FlatpakRemote       *remote,
                                                                          GCancellable        *cancellable,
@@ -268,6 +296,8 @@ FLATPAK_EXTERN char *                flatpak_installation_get_config (FlatpakIns
                                                                       const char          *key,
                                                                       GCancellable        *cancellable,
                                                                       GError             **error);
+FLATPAK_EXTERN char **               flatpak_installation_get_default_languages (FlatpakInstallation  *self,
+                                                                                 GError              **error);
 FLATPAK_EXTERN char *              flatpak_installation_load_app_overrides (FlatpakInstallation *self,
                                                                             const char          *app_id,
                                                                             GCancellable        *cancellable,
@@ -362,6 +392,11 @@ FLATPAK_EXTERN GPtrArray    *    flatpak_installation_list_remote_refs_sync (Fla
                                                                              const char          *remote_or_uri,
                                                                              GCancellable        *cancellable,
                                                                              GError             **error);
+FLATPAK_EXTERN GPtrArray    *    flatpak_installation_list_remote_refs_sync_full (FlatpakInstallation *self,
+                                                                                  const char          *remote_or_uri,
+                                                                                  FlatpakQueryFlags    flags,
+                                                                                  GCancellable        *cancellable,
+                                                                                  GError             **error);
 FLATPAK_EXTERN FlatpakRemoteRef  *flatpak_installation_fetch_remote_ref_sync (FlatpakInstallation *self,
                                                                               const char          *remote_name,
                                                                               FlatpakRefKind       kind,
@@ -370,6 +405,15 @@ FLATPAK_EXTERN FlatpakRemoteRef  *flatpak_installation_fetch_remote_ref_sync (Fl
                                                                               const char          *branch,
                                                                               GCancellable        *cancellable,
                                                                               GError             **error);
+FLATPAK_EXTERN FlatpakRemoteRef  *flatpak_installation_fetch_remote_ref_sync_full (FlatpakInstallation *self,
+                                                                                   const char          *remote_name,
+                                                                                   FlatpakRefKind       kind,
+                                                                                   const char          *name,
+                                                                                   const char          *arch,
+                                                                                   const char          *branch,
+                                                                                   FlatpakQueryFlags    flags,
+                                                                                   GCancellable        *cancellable,
+                                                                                   GError             **error);
 FLATPAK_EXTERN gboolean          flatpak_installation_update_appstream_sync (FlatpakInstallation *self,
                                                                              const char          *remote_name,
                                                                              const char          *arch,
